@@ -1,14 +1,14 @@
 package Data::Sah::Coerce::perl::To_int::From_str::tz_offset_strings;
 
-# AUTHOR
-our $DATE = '2021-08-04'; # DATE
-our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.017'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-10-12'; # DATE
+our $DIST = 'Sah-Schemas-Date'; # DIST
+our $VERSION = '0.018'; # VERSION
+
 sub meta {
     +{
         v => 4,
@@ -54,7 +54,7 @@ Data::Sah::Coerce::perl::To_int::From_str::tz_offset_strings - Convert timezone
 
 =head1 VERSION
 
-This document describes version 0.017 of Data::Sah::Coerce::perl::To_int::From_str::tz_offset_strings (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
+This document describes version 0.018 of Data::Sah::Coerce::perl::To_int::From_str::tz_offset_strings (from Perl distribution Sah-Schemas-Date), released on 2022-10-12.
 
 =head1 SYNOPSIS
 
@@ -90,6 +90,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Date>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Date>
@@ -98,15 +127,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
