@@ -1,12 +1,14 @@
 package Sah::Schema::date::month::en;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-04'; # DATE
+our $DATE = '2022-10-12'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 our $schema = [cistr => {
-    summary => 'Month number/name (abbreviated or full, in English)',
+    summary => 'Month number/name (abbreviated or full, in English), e.g. 1 or "jan" or "September"',
     in => [
         1..12,
         qw/jan feb mar apr may jun jul aug sep oct nov dec/,
@@ -35,7 +37,7 @@ _
 
 1;
 
-# ABSTRACT: Month number/name (abbreviated or full, in English)
+# ABSTRACT: Month number/name (abbreviated or full, in English), e.g. 1 or "jan" or "September"
 
 __END__
 
@@ -45,11 +47,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::month::en - Month number/name (abbreviated or full, in English)
+Sah::Schema::date::month::en - Month number/name (abbreviated or full, in English), e.g. 1 or "jan" or "September"
 
 =head1 VERSION
 
-This document describes version 0.017 of Sah::Schema::date::month::en (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
+This document describes version 0.018 of Sah::Schema::date::month::en (from Perl distribution Sah-Schemas-Date), released on 2022-10-12.
 
 =head1 SYNOPSIS
 
@@ -77,7 +79,7 @@ To check data against this schema (requires L<Data::Sah>):
  my $validator = gen_validator("date::month::en*");
  say $validator->($data) ? "valid" : "INVALID!";
 
-The above schema returns a boolean value (true if data is valid, false if
+The above schema returns a boolean result (true if data is valid, false if
 otherwise). To return an error message string instead (empty string if data is
 valid, a non-empty error message otherwise):
 
@@ -89,7 +91,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "";
+ $data = "foo";
  my $errmsg = $validator->($data); # => "Must be one of [1,2,3,4,5,6,7,8,9,10,11,12,\"jan\",\"feb\",\"mar\",\"apr\",\"may\",\"jun\",\"jul\",\"aug\",\"sep\",\"oct\",\"nov\",\"dec\",\"january\",\"february\",\"march\",\"april\",\"june\",\"july\",\"august\",\"september\",\"october\",\"november\",\"december\"]"
 
 Often a schema has coercion rule or default value, so after validation the
@@ -104,10 +106,10 @@ prefiltered) value:
  my $res = $validator->($data); # => ["","FeB"]
  
  # a sample invalid data
- $data = "";
- my $res = $validator->($data); # => ["Must be one of [1,2,3,4,5,6,7,8,9,10,11,12,\"jan\",\"feb\",\"mar\",\"apr\",\"may\",\"jun\",\"jul\",\"aug\",\"sep\",\"oct\",\"nov\",\"dec\",\"january\",\"february\",\"march\",\"april\",\"june\",\"july\",\"august\",\"september\",\"october\",\"november\",\"december\"]",""]
+ $data = "foo";
+ my $res = $validator->($data); # => ["Must be one of [1,2,3,4,5,6,7,8,9,10,11,12,\"jan\",\"feb\",\"mar\",\"apr\",\"may\",\"jun\",\"jul\",\"aug\",\"sep\",\"oct\",\"nov\",\"dec\",\"january\",\"february\",\"march\",\"april\",\"june\",\"july\",\"august\",\"september\",\"october\",\"november\",\"december\"]","foo"]
 
-Data::Sah can also create validator that returns a hash of detaild error
+Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
 JavaScript, from the same schema. Other things Data::Sah can do: show source
 code for validator, generate a validator code with debug comments and/or log
@@ -168,6 +170,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'DateMonthEn')
+     );
+ }
+
+ use My::Types qw(DateMonthEn);
+ DateMonthEn->assert_valid($data);
+
 =head1 DESCRIPTION
 
 Note that name is not coerced to number; use
@@ -185,6 +204,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Date>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Date>
@@ -193,15 +241,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
