@@ -1,12 +1,14 @@
 package Sah::Schema::date::tz_offset_lax;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-04'; # DATE
+our $DATE = '2022-10-12'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 our $schema = ['date::tz_offset' => {
-    summary => 'Timezone offset in seconds from UTC',
+    summary => 'Timezone offset in seconds from UTC (any offset is allowed, coercible from string), e.g. 1 or 25200 e.g. UTC+7',
     'merge.delete.in' => [],
     min => -12*3600,
     max => +14*3600,
@@ -44,7 +46,7 @@ _
 
 1;
 
-# ABSTRACT: Timezone offset in seconds from UTC
+# ABSTRACT: Timezone offset in seconds from UTC (any offset is allowed, coercible from string), e.g. 1 or 25200 e.g. UTC+7
 
 __END__
 
@@ -54,11 +56,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::tz_offset_lax - Timezone offset in seconds from UTC
+Sah::Schema::date::tz_offset_lax - Timezone offset in seconds from UTC (any offset is allowed, coercible from string), e.g. 1 or 25200 e.g. UTC+7
 
 =head1 VERSION
 
-This document describes version 0.017 of Sah::Schema::date::tz_offset_lax (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
+This document describes version 0.018 of Sah::Schema::date::tz_offset_lax (from Perl distribution Sah-Schemas-Date), released on 2022-10-12.
 
 =head1 SYNOPSIS
 
@@ -96,7 +98,7 @@ To check data against this schema (requires L<Data::Sah>):
  my $validator = gen_validator("date::tz_offset_lax*");
  say $validator->($data) ? "valid" : "INVALID!";
 
-The above schema returns a boolean value (true if data is valid, false if
+The above schema returns a boolean result (true if data is valid, false if
 otherwise). To return an error message string instead (empty string if data is
 valid, a non-empty error message otherwise):
 
@@ -104,7 +106,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "UTC";
+ $data = "UTC+12:01";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -119,14 +121,14 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "UTC";
- my $res = $validator->($data); # => ["",0]
+ $data = "UTC+12:01";
+ my $res = $validator->($data); # => ["",43260]
  
  # a sample invalid data
  $data = "";
  my $res = $validator->($data); # => ["Cannot be empty",""]
 
-Data::Sah can also create validator that returns a hash of detaild error
+Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
 JavaScript, from the same schema. Other things Data::Sah can do: show source
 code for validator, generate a validator code with debug comments and/or log
@@ -187,6 +189,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'DateTzOffsetLax')
+     );
+ }
+
+ use My::Types qw(DateTzOffsetLax);
+ DateTzOffsetLax->assert_valid($data);
+
 =head1 DESCRIPTION
 
 This schema allows timezone offsets that are not known to exist, e.g. 1 second
@@ -210,6 +229,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Date>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Date>
@@ -218,15 +266,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
